/**
 * @internal
 */
export declare const AWS_EXECUTION_ENV = "AWS_EXECUTION_ENV";
/**
 * @internal
 */
export declare const AWS_REGION_ENV = "AWS_REGION";
/**
 * @internal
 */
export declare const AWS_DEFAULT_REGION_ENV = "AWS_DEFAULT_REGION";
/**
 * @internal
 */
export declare const ENV_IMDS_DISABLED = "AWS_EC2_METADATA_DISABLED";
/**
 * @internal
 */
export declare const DEFAULTS_MODE_OPTIONS: string[];
/**
 * @internal
 */
export declare const IMDS_REGION_PATH = "/latest/meta-data/placement/region";
