import { LoadedConfigSelectors } from "@smithy/node-config-provider";
import { DefaultsMode } from "@smithy/smithy-client";
/**
 * @internal
 */
export declare const NODE_DEFAULTS_MODE_CONFIG_OPTIONS: LoadedConfigSelectors<DefaultsMode>;
